@@ -59,7 +59,7 @@ class ULSetActionFrame(ULActionNode):
             return
 
         action = self.act_system.get_layer(game_object, action_layer)
-        same_action = action == action_name
+        same_action = action is not None and action.name == action_name
         if not same_action or action is None:
             action = bpy.data.actions[action_name]
             start_frame = action.frame_range[0]
@@ -73,7 +73,8 @@ class ULSetActionFrame(ULActionNode):
                 layer_weight=layer_weight
             )
 
-        action.frame = action_frame
+        game_object.setActionFrame(action_frame, action_layer)
         if freeze:
-            action.pause()
+            action.speed = 0
         action.layer_weight = layer_weight
+        self.done = True
