@@ -2,6 +2,7 @@ from bge import logic
 
 
 class ULCollision():
+    """Collision Handler. Not intended for manual use."""
     target = None
     point = None
     normal = None
@@ -62,5 +63,13 @@ class ULCollision():
         logic.getCurrentScene().post_draw.remove(self.update)
 
 
-def on_collision(obj, callback, prop='', material='', tap=False):
+def on_collision(obj, callback, prop='', material='', tap=False) -> ULCollision:
+    """Bind a callback to an object's collision detection.
+
+    :param `obj`: Object whose collision detection will be used.
+    :param `callback`: Callback to be called when collision occurs. Must have arguments `(obj, point, norma)`.
+    :param `prop`: Only look for objects that have this property.
+    :param `material`: Only look for objects that have this material applied.
+    :param `tap`: Only validate the first frame of the collision.
+    """
     return ULCollision(obj, callback, prop, material, tap)
